@@ -1,19 +1,7 @@
-/***************************************************************************
-                                 kwordquiz.h
-                             -------------------
-    begin                : Wed Jul 24 20:12:30 PDT 2002
-    copyright            : (C) 2002-2010 by Peter Hedlund
-    email                : peter.hedlund@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002-2010 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KWORDQUIZ_H
 #define KWORDQUIZ_H
@@ -130,10 +118,10 @@ class KWordQuizApp : public KXmlGuiWindow
      */
     void readProperties(const KConfigGroup &_cfg) override;
 
-  signals:
+  Q_SIGNALS:
     void settingsChanged();
 
-  public slots:
+  public Q_SLOTS:
     /** open a new application window by creating a new instance of KWordQuizApp */
     void slotFileNew();
     /** open a file and load it into the document*/
