@@ -1,18 +1,7 @@
-/***************************************************************************
-                              kwqcardscene.cpp
-                             -------------------
-   copyright            : (C) 2009-2011 by Peter Hedlund
-   email                : peter.hedlund@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2011 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kwqcardscene.h"
 
@@ -150,6 +139,6 @@ void KWQCardScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
     QGraphicsItem *item = itemAt(mouseEvent->scenePos(), QTransform());
     if (item != 0)
-        emit cardClicked();
+        Q_EMIT cardClicked();
     QGraphicsScene::mouseReleaseEvent(mouseEvent);
 }
