@@ -1,20 +1,7 @@
-/***************************************************************************
-                               kwqquizmodel.cpp
-                             -------------------
-
-    copyright            : (C) 2008-2010 by Peter Hedlund
-    email                : peter.hedlund@kdemail.net
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kwqquizmodel.h"
 
@@ -335,9 +322,9 @@ QString KWQQuizModel::question()
     }
 
     if (m_quizType != Prefs::EnumStartSession::Flashcard && m_currentQuestion > 0)
-        emit checkingAnswer(m_list.at(m_currentQuestion - 1));
+        Q_EMIT checkingAnswer(m_list.at(m_currentQuestion - 1));
     else
-        emit checkingAnswer(row);
+        Q_EMIT checkingAnswer(row);
 
     return s;
 }
@@ -487,7 +474,7 @@ int KWQQuizModel::questionCount()
 
 void KWQQuizModel::finish()
 {
-    emit checkingAnswer(-1);
+    Q_EMIT checkingAnswer(-1);
 }
 
 
