@@ -1,20 +1,7 @@
-/***************************************************************************
-                                 kwqtutor.h
-                             -------------------
-
-    copyright            : (C) 2010 by Peter Hedlund
-    email                : peter.hedlund@kdemail.net
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KWQTUTOR_H
 #define KWQTUTOR_H
@@ -34,7 +21,7 @@ class KWQTutor : public KStatusNotifierItem
     /* init systray icon, meny, actions */
     explicit KWQTutor (const QUrl &fileToOpen, QWidget *parent = nullptr);
 
-  public slots:
+  public Q_SLOTS:
     /* self-calling function: it sets the time interval,calls itself and call func to display flashcard*/
     void updateTimer();
     /*open keduvocdocument from the menu */
